namespace efl { namespace loop { 
inline ::efl::eolian::return_traits<double>::type Timer::interval_get() const
{
   double __return_value =  ::efl_loop_timer_interval_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Timer::interval_set( ::efl::eolian::in_traits<double>::type in) const
{
    ::efl_loop_timer_interval_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(in));
}
inline ::efl::eolian::return_traits<double>::type Timer::pending_get() const
{
   double __return_value =  ::efl_loop_timer_pending_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Timer::reset() const
{
    ::efl_loop_timer_reset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Timer::loop_reset() const
{
    ::efl_loop_timer_loop_reset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Timer::delay( ::efl::eolian::in_traits<double>::type add) const
{
    ::efl_loop_timer_delay(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(add));
}
} } 
namespace eo_cxx {
namespace efl { namespace loop { 
inline ::efl::eolian::return_traits<double>::type Timer::interval_get() const
{
   double __return_value =  ::efl_loop_timer_interval_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Timer::interval_set( ::efl::eolian::in_traits<double>::type in) const
{
    ::efl_loop_timer_interval_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(in));
}
inline ::efl::eolian::return_traits<double>::type Timer::pending_get() const
{
   double __return_value =  ::efl_loop_timer_pending_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Timer::reset() const
{
    ::efl_loop_timer_reset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Timer::loop_reset() const
{
    ::efl_loop_timer_loop_reset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Timer::delay( ::efl::eolian::in_traits<double>::type add) const
{
    ::efl_loop_timer_delay(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(add));
}
inline efl::loop::Timer::operator ::efl::loop::Timer() const { return *static_cast< ::efl::loop::Timer const*>(static_cast<void const*>(this)); }
inline efl::loop::Timer::operator ::efl::loop::Timer&() { return *static_cast< ::efl::loop::Timer*>(static_cast<void*>(this)); }
inline efl::loop::Timer::operator ::efl::loop::Timer const&() const { return *static_cast< ::efl::loop::Timer const*>(static_cast<void const*>(this)); }
} } }

